@@ -16,7 +16,7 @@ WebService::Audioscrobbler - An object-oriented interface to the Audioscrobbler
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 CLASS->mk_classaccessor("base_url"     => URI->new("http://ws.audioscrobbler.com/1.0/"));
 
@@ -163,7 +163,7 @@ sub user {
 
 =head1 AUTHOR
 
-Nilson Santos Figueiredo Junior, C<< <nilsonsfj at cpan.org> >>
+Nilson Santos Figueiredo Jnior, C<< <nilsonsfj at cpan.org> >>
 
 =head1 BUGS
 
@@ -203,11 +203,28 @@ L<http://search.cpan.org/dist/WebService-Audioscrobbler>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006 Nilson Santos Figueiredo Junior, all rights reserved.
+Copyright 2006 Nilson Santos Figueiredo Jnior, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+B<NOTE>: The datafeed from audioscrobbler.net is for
+I<non-commercial use only>. Please see 
+L<http://www.audioscrobbler.net/data/webservices/> for
+more licensing information.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<http://www.audioscrobbler.net/data/webservices/> and L<http://www.last.fm/>
+
+=item * L<WebService::LastFM::SimilarArtists>, L<WebServices::LastFM>, L<Audio::Scrobbler>
+
+=item * L<LWP::Simple>, L<URI>, L<XML::Simple>
+
+=back
+
 =cut
 
 1; # End of WebService::Audioscrobbler
